function [Rp,Sp,nrp,nsp]=bezoutd(A,B,Hs,Hr,P)
% solve AS+BR=P by coefficient comparison [Rp,Sp,nrp,nsp]=bezoutd(A,B,Hs,Hr,P)
% delay and discretization delay need to be integrated in B
% R=Hr*Rp   S=Hs*Sp
global PRECISION;

D=size(A);
if D(1)>1 A=A'; end;

D=size(B);
if D(1)>1 B=B'; end;

D=size(Hs);
if D(1)>1 Hs=Hs'; end;
if D(1)==0 Hs=1; end;

D=size(Hr);
if D(1)>1 Hr=Hr'; end;
if D(1)==0 Hr=1;end;

D=size(P);
if D(1)>1 P=P'; end;

% remove trailing zeros in A and B
index=max(find(abs(A)>PRECISION));
if (index<length(A))
	A=A(1:index);
end;
index=max(find(abs(B)>PRECISION)); 
if (index<length(B))
        B=B(1:index);
end;
     
%while(abs(A(length(A)))<PRECISION)&(abs(B(length(A)))<PRECISION)
 %  A=A(1:(length(A)-1));
%   B=B(1:(length(B)-1));
%end;

na=length(A)-1;
nb=length(B)-1;
np=length(P)-1;
nhs=length(Hs)-1;
nhr=length(Hr)-1;

Ah=real(conv(A,Hs));

nah=length(Ah) -1;
if (nah~= na+nhs) disp('bezoutb.m: error in Ah');end;

Bh=real(conv(B,Hr));

nbh=length(Bh) -1;
if (nbh~= nb +nhr) disp('bezoutb.m: error in Bh');end;

if (np>nah+nbh-1) disp('Bezout error: too many poles');end;


 % test if Ah and Bh are coprime
 %[Ahnew,Bhnew]=adjlen(Ah,Bh);% adjust length of a shorter vector by zeros
v1=Ah;v2=Bh;
l1=length(v1);
l2=length(v2);
if (l1<l2)
	Ahnew=[v1,zeros(1,l2-l1)]; Bhnew=v2;
elseif (l1>l2)
	Bhnew=[v2,zeros(1,l1-l2)]; Ahnew=v1;
else
	Ahnew=v1;Bhnew=v2;
end;
maxlen=length(Ahnew);


% removing of a common factor from A and B
[Bhnew2,Ahnew2]=minreal(Bhnew,Ahnew);
%Bhnew2=Bhnew;Ahnew2=Ahnew;

if (length(Ahnew2)==maxlen)
 % everything is fine, no simplification
else
 simplnum=maxlen-length(Ahnew2);
 % find lacking factor in Ahnew2
 [quotient,remainder]=deconv(Ahnew,Ahnew2);
 quotorder=length(quotient)-1;
 % remove this factor from Ah and Bh
 [Ah,remainder]=deconv(Ah,quotient);
 [Bh,remainder]=deconv(Bh,quotient);
 nah=nah-quotorder;
 nbh=nbh-quotorder;
end; % if (length(Ahnew2)==maxlen)
% result in Ah, Bh



% increase size of P using zeros if necessary
if (np<nah+nbh-1)
% 	P=[P zeros(1,nah+nbh-1-np)];
% set remaining poles onto a circle with radius rmin
	rootsPdes=roots(P);
	nextra=nah+nbh-1-np;
	rmin=1e-16;
	angle=[0:nextra-1]'/nextra*2*pi;
	j=sqrt(-1);
	rootsPextra=rmin*exp(j*angle);
	P=poly([rootsPdes;rootsPextra]);
	np=nah+nbh-1;
end;

nsp=nbh-1;
nrp=nah-1;

%matrix is smaller than vector PD
if (np>nah+nbh-1) 
   prompt='It is specified too many poles!\n ';
   msgbox(prompt,'Bezout equation ERROR');
   A,
   B,
   Ah,
   Bh,
   Hr,
   Hs,
   P,
end;

% ns=nsp+nhs
% nr=nrp+nhr

M=[];
for j=1:nsp+1 
	V=[];
	if (j>1) V=[V ; zeros(j-1,1)]; end;% zeros in front of Ah
	V=[V ; Ah'];% Ah
	if (j<=nsp) V=[V ; zeros(nsp+1-j,1)]; end;% zeros behind Ah
	if (length(V)~=nah+nbh) disp('bezoutb: error V'); end;
  	M=[M V]; % add one column to M
end;

for j=1:nrp+1 
	V=[];
	if (j>1) V=[V ; zeros(j-1,1)]; end;
	V=[V ; Bh'];
	if (j<=nrp) V=[V ; zeros(nrp+1-j,1)]; end;
   if (length(V)~=nah+nbh) disp('bezoutb: error V'); end;
  	M=[M V];
end;

D=size(M);
if (D(1)~=nah+nbh) disp('bezoutb: error size M row'); end;
if (D(2)~=nah+nbh) disp('bezoutb: error size M column'); end;

% make P column vector
P=P';


global M1;
M1=M;

X= M\P;
% coefficients are real values
X=real(X);

% make X row vector
X=X';
Sp=X(1:nsp+1);
Rp=X(nsp+2:nsp+nrp+2);

global hvec_ctrlstab;
if ~isempty(hvec_ctrlstab),
	r=roots(Sp);
   axes(hvec_ctrlstab(2));
   hold off;
   plot(real(r),imag(r),'rx');
   zgrid;
   title('Controller Pole-Zero Map');
   xlabel('Real');
   ylabel('Imag');
   if max(abs(r))>1, 
      set(hvec_ctrlstab(3),'String','NO');
   else
      set(hvec_ctrlstab(3),'String','YES');      
   end;
end;

