function ppmaster;
%------------------- Pole Placement Master -------------------
%
%is an interactive toolbox for robust SISO controller design 
%by pole placement with sensitivity function shaping. The 
%toolbox is primary made for Matlab 5.3, but with some 
%limitations it works also under Matlab 6.5.
%
%1) To run Pole-Placement Master (ppmaster):
%   - run Matlab.
%   - go to the directory with m-files / p-files of ppmaster or 
%     add this directory to the path variable (for example using 
%     path-browser).
%   - type "ppmaster".
%
%To load a model and start design you go to : 
%   Model->Load model->Matlab format
%                      WinPim format
%
%2) To load a whole design workspace (two examples are in the 
%directory "Examples") go to :
%   Model->Current Parameter Set->Load Parameters and model
%
%3) To save a whole design workspace go to :
%   Model->Current Parameter Set->Save Parameters and model
%
%*************************************************************
% ATTENTION !!!: The Matlab 5.3 does not recognise well the 
% directories with name containing some spaces 
% (example: "\Documents and Settings"). Preferably, place the 
% ppmaster to some directory with the name without any space.
%*************************************************************
%
%For more information on toolbox see \Help\ppm_help.pdf file. 


%start function
clear all;
close all;
echo on;disp('--------------------   P O L E   P L A C E M E N T   M A S T E R 2.0 ------------------');echo off;
echo on;disp('----- Authors:    Hynek Prochazka                                                 -----');echo off;
echo on;disp('-----             Ioan Dor Landau                                                -----');echo off;
echo on;disp('----- University: INPG-ENSIEG-Laboratoire d''Automatique de Grenoble               -----');echo off;
echo on;disp('---------------------------------------------------------------------------------------');echo off;


%load configuration
global PRECISION;
global xscal yscal Nf_points F_lin_log;
global colorset;

PRECISION= 1e-10;
xscal= 1;%Hz
yscal= 1;%dB
Nf_points=512;%number of frequency points for sensitivity display
F_lin_log=1;%linear or logarithmic frequency scale (equidistant or log. distribution of frequency points)
%------------------------------------- Colors
Background= [0.501960784313725 0.501960784313725 0.250980392156863];
Axes= [1 1 1];
Template= [0 0 0];
Current= [1 0 0];
Held= [0.27 0.44 0.47];


colorset=struct('Background',Background,'Axes',Axes,'Template',Template,'Current',Current,'Held',Held);

mainwin(0);