function auxpol(par);
%function with methods for auxiliary poles window
global Ts;
PREC=1e-8;
MINF=1/(1000*Ts);
MAXF=1/(2*Ts);
MINDM=PREC;
MAXDM=1;
MINCF=-0.99;
MAXCF=1;
MINN=1;

if par==0, %init for window
   global PAuxiliary;
   global A B PD AP Hr Hs Ts Wsup Wsypu fn Ts;
	global Sypf_num Sypf_den Supf_num Supf_den; %numerators and denominators of 2poles/2zeros filters for Syp and Sup 
	global Sypf Supf; %flags for the filters
   global hn_aux;
   
   n=nmax_compute;%number of free poles
   if (n<=0)&isempty(PAuxiliary),
      warndlg('Can not performe, remove some of auxiliary poles first!');
      return;
   end;
   global auxp_var;
   auxp_var=struct('A',A,'B',B,'Hr',Hr,'Hs',Hs,'PD',PD,'AP',AP,'Ts',Ts, ...
      'sypfnum',Sypf_num,'sypfden',Sypf_den,'supfnum',Supf_num,'supfden',Supf_den, ...
      'Wsup',Wsup,'Wsyp',Wsypu,'Wfn',fn/Ts,'saux',PAuxiliary, ...
      'MAXN',0,'poles',[],'hsfun',[],'hsfun2',[], 'hfposup',[],'hfposyp',[]);
   
   if Sypf==0, auxp_var.sypfnum=1;auxp_var.sypfden=1;end;
   if Supf==0, auxp_var.supfnum=1;auxp_var.supfden=1;end;   
   %   auxp_var.saux=[struct('pair',1,'fq_cf',0,'dmp_n',0)]; if pair==1 =>pair of complex poles ;pair==0 =>pole multiple
   auxp_var.MAXN=n;%number of free poles
	auxpolw;%window
	global hvec_auxp;
	%hvec_auxp=[h0 hax_syp hax_sup hlst_mod hsld_fq htxt_fq htxt_ftx hsld_dmp htxt_dmp htxt_dtx ...
	%   	   hlst_aux hpop_aux htxt_aux];
	%model poles 
	listp={};
	[mag,w,xi]=ddamp(A,Ts);
	K=1;
   for K=1:length(w),
      s=sprintf('p(%d): %gHz ;%g',K,w(K)/(2*pi),xi(K));
	   listp(K)=cellstr(s);
	end;
   set(hvec_auxp(4),'String',listp);
   set(hvec_auxp(12),'String',{'Complex Poles','Multiple Pole'});
   s=sprintf('Poles to add: %d',auxp_var.MAXN);
   set(hvec_auxp(13),'String',s);
   %list of aux. poles and slides
   if isempty(auxp_var.saux),%disable
      set(hvec_auxp(5),'enable','off');
      set(hvec_auxp(8),'enable','off');      
   else
      %list of poles
	   listp={};
	   for k=1:length(auxp_var.saux),
	      v=auxp_var.saux(k);
	      if v.pair==1, %oscillatory
	         s=sprintf('%cplx p.: gHz, %gi',v.fq_cf,v.dmp_n);
	      elseif(v.pair==0),
   	      s=sprintf('%mult p.: g, N=%gi',v.fq_cf,v.dmp_n);
	      end;
		   listp(K)=cellstr(s);
		end;
	   set(hvec_auxp(11),'String',listp,'Value',1);   
      %slides
      auxpol(8);
   end;
	auxpol(4);%redraw
	   
elseif(par==1), %OK button
   global PAuxiliary;
   global hvec_auxp;
   global auxp_var;
	PAuxiliary=auxp_var.saux;
	close(hvec_auxp(1));
   change(13); %recompute the functions
   
elseif(par==2), %Cancel button
   global hvec_auxp;
	close(hvec_auxp(1));
	   
elseif(par==3), %deletefcn
   global hvec_auxp;
   global auxp_var;
	clear global hvec_auxp auxp_var;   
   
elseif(par==4), %redraw functions
   global hvec_auxp;
   global auxp_var;
   global xscal yscal;
%hvec_auxp=[h0 hax_syp hax_sup hlst_mod hsld_fq htxt_fq htxt_ftx hsld_dmp htxt_dmp htxt_dtx ...
%   	   hlst_aux hpop_aux htxt_aux];
   hsapp=conv(auxp_var.Hs,auxp_var.sypfnum);
   hrapp=conv(auxp_var.Hr,auxp_var.supfnum);
   paux=evalaux(auxp_var.saux);%evaluation of the structure
   Papp=conv(auxp_var.PD, conv(auxp_var.AP, conv(auxp_var.sypfden, conv(auxp_var.supfden,paux))));
   [r,s,nr,ns]=bezout(auxp_var.A,auxp_var.B,hsapp,hrapp,Papp);
   sypnum=conv(auxp_var.A,conv(s,hsapp));
   supnum=conv(auxp_var.A,conv(r,hrapp));
   denom=addvec(sypnum,conv(auxp_var.B,conv(r,hrapp)));
   %draw Syp
   [s,f]=freqz(sypnum,denom,512,1/auxp_var.Ts);
   s=abs(s);
   ft=auxp_var.Wfn;
   sx='frequency [Hz]';
   sy='Magnitude of Syp [-]';
   if (xscal==2), 
      f=2*pi*f;
		ft=auxp_var.Wfn*2*pi;      
	   sx='frequency [rad/s]';         
   elseif(xscal==3), 
      f=f*auxp_var.Ts;
      sx='frequency f/f_s[-]';         
		ft=auxp_var.Wfn*auxp_var.Ts;      
   end;
   if (yscal==1), 
      for k=1:length(s), if s(k)<PREC, s(k)=PREC;end;end;         
      s=20*log10(s);
      sy='Magnitude of Syp [dB]';            
      templ=auxp_var.Wsyp;
   elseif(yscal==2),%linear
      templ=10.^(auxp_var.Wsyp/20);
   end;
	axes(hvec_auxp(2));
   if isempty(auxp_var.hsfun),
		hold off;
		plot(ft,templ,'k');
		hold on;
      auxp_var.hsfun=plot(f,s,'r');
	   title(sy);      
   else
		set(auxp_var.hsfun,'YData',s);
   end;
   grid on;
   %draw Sup
   [s,f]=freqz(supnum,denom,512,1/auxp_var.Ts);
   s=abs(s);
   ft=auxp_var.Wfn;%freq of templates
   sx='frequency [Hz]';
   sy='Magnitude of Sup [-]';
   if (xscal==2), 
      f=2*pi*f;
      ft=auxp_var.Wfn*2*pi;
   sx='frequency [rad/s]';         
   elseif(xscal==3), 
      f=f*auxp_var.Ts;
      sx='frequency f/f_s[-]';  
      ft=auxp_var.Wfn*auxp_var.Ts;
   end;
   if (yscal==1), 
      for k=1:length(s), if s(k)<PREC, s(k)=PREC;end;end;         
      s=20*log10(s);
      sy='Magnitude of Sup [dB]';            
      templ=auxp_var.Wsup;
   elseif(yscal==2),%linear
      templ=10.^(auxp_var.Wsup/20);
   end;
	axes(hvec_auxp(3));
   if isempty(auxp_var.hsfun2),
		hold off;
		plot(ft,templ,'k');
		hold on;
      auxp_var.hsfun2=plot(f,s,'r');
      title(sy);      
      xlabel(sx);
   else
		set(auxp_var.hsfun2,'YData',s);
   end;
   grid on;
   y=get(hvec_auxp(2),'Ylim');
   if y(1)<-60, y(1)=-60;set(hvec_auxp(2),'Ylim',y);end;
   y=get(hvec_auxp(3),'Ylim');
   if y(1)<-60, y(1)=-60;set(hvec_auxp(3),'Ylim',y);end;
   
elseif(par==5), %modify actual poles
   global hvec_auxp;
   global auxp_var;
%hvec_auxp=[h0 hax_syp hax_sup hlst_mod hsld_fq htxt_fq htxt_ftx hsld_dmp htxt_dmp htxt_dtx ...
%   	   hlst_aux hpop_aux htxt_aux];
	inx=get(hvec_auxp(11),'Value');
   sl1=get(hvec_auxp(5),'Value');
	sl2=get(hvec_auxp(8),'Value');   
   v=auxp_var.saux(inx);
   if v.pair==1,%oscillatory poles
      v.fq_cf=MINF+(MAXF-MINF)*sl1;
      v.dmp_n=MINDM+(MAXDM-MINDM)*sl2;
      n_out=0;
   elseif v.pair==0, %multiple pole
      v.fq_cf=MINCF+(MAXCF-MINCF)*sl1;
      n_out=MINN+((v.dmp_n+auxp_var.MAXN)-MINN)*sl2;
      if abs(v.dmp_n-round(n_out))<PREC, 
         if (v.dmp_n>n_out)&(v.dmp_n>MINN), 
            v.dmp_n=v.dmp_n-1;
            n_out=-1;
         elseif (v.dmp_n<n_out)&(auxp_var.MAXN>0),
            v.dmp_n=v.dmp_n+1;
            n_out=1;
         else
            n_out=0;
         end;
      else
         n_n=round(n_out)-v.dmp_n;                  
         v.dmp_n=round(n_out);
			n_out=n_n;
      end;
   end;
   auxp_var.saux(inx)=v;
   auxp_var.MAXN=auxp_var.MAXN-n_out;
   auxpol(8);%callback for list
   auxpol(4);%redraw
   
elseif(par==6), %add poles
   global hvec_auxp;
   global auxp_var;
%hvec_auxp=[h0 hax_syp hax_sup hlst_mod hsld_fq htxt_fq htxt_ftx hsld_dmp htxt_dmp htxt_dtx ...
%   	   hlst_aux hpop_aux htxt_aux];
	pair=get(hvec_auxp(12),'Value');
	if pair==2, pair=0;end;%multiple pole
   if (pair==1)&(auxp_var.MAXN<2), return;end;
   if (pair==0)&(auxp_var.MAXN<1), return;end;   
   if pair==1, %oscillatory poles
      inx=get(hvec_auxp(4),'Value');%index of actual model pole
      [mag,w,xi]=ddamp(auxp_var.A,auxp_var.Ts);
      if (w(inx)<MAXF*2*pi)&(w(inx)>MINF*2*pi)&(xi(inx)<MAXDM)&(xi(inx)>MINDM),
         v=struct('pair',1,'fq_cf',w(inx)/(2*pi),'dmp_n',xi(inx));
      else
         v=struct('pair',1,'fq_cf',MINF+((MAXF-MINF)/2),'dmp_n',MINDM+((MAXDM-MINDM)/2));
      end;
      n_out=2;
   elseif(pair==0), %multiple
      inx=get(hvec_auxp(4),'Value');%index of actual model pole
      [mag,w,xi]=ddamp(auxp_var.A,auxp_var.Ts);
      if (w(inx)<MAXF*2*pi)&(w(inx)>MINF*2*pi)&(abs(xi(inx)-1)<PREC),
         v=struct('pair',0,'fq_cf',mag(inx),'dmp_n',1);
      else
         v=struct('pair',0,'fq_cf',MINCF+((MAXCF-MINCF)/2),'dmp_n',1);
      end;
      n_out=1;
   end;
   auxp_var.saux=[auxp_var.saux;v];   
   auxp_var.MAXN=auxp_var.MAXN-n_out;
   auxpol(8);%callback for list
   auxpol(4);%redraw
   
elseif(par==7), %remove poles
   global hvec_auxp;
   global auxp_var;
%hvec_auxp=[h0 hax_syp hax_sup hlst_mod hsld_fq htxt_fq htxt_ftx hsld_dmp htxt_dmp htxt_dtx ...
%   	   hlst_aux hpop_aux htxt_aux];
	inx=get(hvec_auxp(11),'Value');
	if inx==0, return; end;
   v=auxp_var.saux;   
   if v(inx).pair==1, n_out=2;elseif(v(inx).pair==0), n_out=v(inx).dmp_n;end;
   if inx<length(v),
      v=[v(1:inx-1);v(inx+1:length(v))];
   else
      v=v(1:inx-1);
   end;
   auxp_var.saux=v;
   auxp_var.MAXN=auxp_var.MAXN+n_out;

   auxpol(8);%callback for list
   auxpol(4);%redraw

elseif(par==8), %callback for auxiliary list
   global hvec_auxp;
   global auxp_var;
%hvec_auxp=[h0 hax_syp hax_sup hlst_mod hsld_fq htxt_fq htxt_ftx hsld_dmp htxt_dmp htxt_dtx ...
%   	   hlst_aux hpop_aux htxt_aux];


	if ~isempty(auxp_var.saux),
		listp={};   
	   for k=1:length(auxp_var.saux),
	      v=auxp_var.saux(k);
	      if (v.pair==1), %oscillatory
	         s=sprintf('cplx: %gHz ;%g',v.fq_cf,v.dmp_n);
	      elseif(v.pair==0),
	  	      s=sprintf('real: %g, ^%g',v.fq_cf,v.dmp_n);
	      end;
		   listp(k)=cellstr(s);
	   end;
      inx=get(hvec_auxp(11),'Value');
      if length(auxp_var.saux)<inx, inx=length(auxp_var.saux);end;
      if inx==0, inx=1;end;
	   set(hvec_auxp(11),'String',listp,'Value',inx);   
	   v=auxp_var.saux(inx);
	   if v.pair==1, %oscillatory
	      val=(v.fq_cf - MINF)/(MAXF - MINF);
		   set(hvec_auxp(5),'enable','on','value',val);
	      set(hvec_auxp(6),'String',num2str(v.fq_cf));
	      set(hvec_auxp(7),'String','Frequency [Hz] ');         
	      val=(v.dmp_n - MINDM)/(MAXDM - MINDM);
	      set(hvec_auxp(8),'enable','on','value',val);
	      set(hvec_auxp(9),'String',num2str(v.dmp_n));
   	   set(hvec_auxp(10),'String','Damping [-] ');         
	   elseif v.pair==0, %real poles
	      val=(v.fq_cf - MINCF)/(MAXCF - MINCF);
	      set(hvec_auxp(5),'enable','on','value',val);
	      set(hvec_auxp(6),'String',num2str(v.fq_cf));
	      set(hvec_auxp(7),'String','Coefficient [-] ');         
	      val=(v.dmp_n - MINN)/((auxp_var.MAXN+v.dmp_n) - MINN);
	      set(hvec_auxp(8),'enable','on','value',val);
	      set(hvec_auxp(9),'String',num2str(v.dmp_n));
	      set(hvec_auxp(10),'String','Order N [-] ');         
   	end;
	   s=sprintf('Poles to add: %d',auxp_var.MAXN);
      set(hvec_auxp(13),'String',s);
   else
	   set(hvec_auxp(5),'enable','off');
      set(hvec_auxp(6),'String','-');
      set(hvec_auxp(8),'enable','off');
      set(hvec_auxp(9),'String','-');
	   s=sprintf('Poles to add: %d',auxp_var.MAXN);
      set(hvec_auxp(13),'String',s);
	   set(hvec_auxp(11),'String','','Value',0);   
	end;      
      
      
      
	end;

   
   
		   
   
	